#!/usr/bin/env python
# coding=utf-8
# USAGE
# python motion_detector.py
# python motion_detector.py --video videos/example_01.mp4


# import the necessary packages
# sudo pip install PiCamera[array]

#This script is used to detect motion from camera connected to raspberry pi
#LED light strip lights when motion is detected
#Gaussian blur is used in motion detection, sensitivity of motion detection
#to adjust change "minimum area size"

import imutils
from imutils.video import VideoStream
import argparse
import datetime
import time, sys
from time import sleep
import cv2
from LEDfunctions import *

#LED for motion detection, when motion is detected, LED is lighted
def vu_2_leds(color):
    while True:
        data = play_process.stdout.readline()
        if not data:
            pixels.clear() # make LEDs dark
            pixels.show()
            break
        data = data.rstrip()
        if data.endswith("%"):
            vu = float(data[:-1][-3:])/100 # 0-100
            leds_color_intensity(color, vu)

def leds_start_stop(color): # for pirate
    while True:
        data = play_process.stdout.readline()
        data = data.rstrip()
        print('data:',data)
        print('process:', play_process.stdout.readline()) #_handle_exitstatus
        leds_pirate_bounce(color_pirate)

# construct the argument parser and parse the arguments
ap = argparse.ArgumentParser()
ap.add_argument("-a", "--min-area", type=int, default=6000, help="minimum area size")
args = vars(ap.parse_args())

# we are reading from the pi camera
vs = VideoStream(usePiCamera=True).start()
sleep(0.5)

# initialize the first frame in the video stream
firstFrame = None
occupied = False

# loop over the frames of the video
while True:
	# grab the current frame and initialize the occupied/unoccupied
	# text
	frame = vs.read()
	frame = frame if args.get("video", None) is None else frame[1]
	text = "Unoccupied"
	# if the frame could not be grabbed, then we have reached the end of the video
	if frame is None:
		break

	# resize the frame, convert it to grayscale, and blur it
	frame = imutils.resize(frame, width=500)
	gray = cv2.cvtColor(frame, cv2.COLOR_BGR2GRAY)
	gray = cv2.GaussianBlur(gray, (21, 21), 0)

	# if the first frame is None, initialize it
	if firstFrame is None:
		firstFrame = gray
		continue

	# compute the absolute difference between the current frame and the first frame
	frameDelta = cv2.absdiff(firstFrame, gray)
	thresh = cv2.threshold(frameDelta, 25, 255, cv2.THRESH_BINARY)[1]

	# dilate the thresholded image to fill in holes, then find contours on thresholded image
	thresh = cv2.dilate(thresh, None, iterations=2)
	cnts = cv2.findContours(thresh.copy(), cv2.RETR_EXTERNAL,
		cv2.CHAIN_APPROX_SIMPLE)
	cnts = cnts[0] if imutils.is_cv2() else cnts[1]

	# loop over the contours
	for c in cnts:
		# if the contour is too small, ignore it
		if cv2.contourArea(c) < args["min_area"]:
			continue

		# compute the bounding box for the contour, draw it on the frame,
		# and update the text
		(x, y, w, h) = cv2.boundingRect(c)
		cv2.rectangle(frame, (x, y), (x + w, y + h), (0, 255, 0), 2)
		text = "Occupied"
		if not occupied:
			occupied = True
			print ('occupied')
            # led activation bounce will preform
			play_process = leds_activation(color_activation)
            # break the while true loop, this will allow the motion.sh loop to preform the second part -> guru-pyrate.py
			sys.exit()

	if occupied and text == "Unoccupied":
		occupied = False
		print ("Unoccupied")


    #check images for debugging

	# # show the frame and record if the user presses a key
	# # cv2.imshow("Security Feed", frame)
	# cv2.imwrite('RegularCamera.jpg', frame)
	# #cv2.imshow("Thresh", thresh)
	# cv2.imwrite('threshold.jpg', thresh)
	# #cv2.imshow("Frame Delta", frameDelta)
	# cv2.imwrite('blured.jpg', frameDelta)
	# #key = cv2.waitKey(1) & 0xFF

	# # if the `q` key is pressed, break from the lop
	# #if key == ord("q"):
	# #	break

# cleanup the camera and close any open windows
vs.stop() if args.get("video", None) is None else vs.release()
#cv2.destroyAllWindows()
